======================================
Aetos Sample Policy Configuration File
======================================

The following is an overview of all available policies in Aetos.
For a sample configuration file, refer to :doc:`sample-policy-yaml`.

.. show-policy::
   :config-file: ../../etc/aetos/aetos-policy-generator.conf
